@@ -26,7 +26,7 @@
 #include <QSortFilterProxyModel>
 #include <Solid/StorageAccess>
 
-class FavoritesModel;
+class SimpleFavoritesModel;
 
 class KConcatenateRowsProxyModel;
 class KFilePlacesModel;
@@ -48,8 +48,8 @@ class FilteredPlacesModel : public QSortFilterProxyModel
         Solid::Device deviceForIndex(const QModelIndex &index) const;
 
     protected:
-        bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const;
-        bool lessThan(const QModelIndex &left, const QModelIndex &right) const;
+        bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const Q_DECL_OVERRIDE;
+        bool lessThan(const QModelIndex &left, const QModelIndex &right) const Q_DECL_OVERRIDE;
 
     private:
         KFilePlacesModel *m_placesModel;
@@ -57,17 +57,19 @@ class FilteredPlacesModel : public QSortFilterProxyModel
 
 class RunCommandModel : public AbstractModel
 {
+    Q_OBJECT
+
     public:
         RunCommandModel(QObject *parent = 0);
         ~RunCommandModel();
 
-        QString description() const;
+        QString description() const Q_DECL_OVERRIDE;
 
-        QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+        QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
 
-        int rowCount(const QModelIndex &parent = QModelIndex()) const;
+        int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
 
-        Q_INVOKABLE bool trigger(int row, const QString &actionId, const QVariant &argument);
+        Q_INVOKABLE bool trigger(int row, const QString &actionId, const QVariant &argument) Q_DECL_OVERRIDE;
 };
 
 class ComputerModel : public ForwardingModel
@@ -82,7 +84,7 @@ class ComputerModel : public ForwardingModel
         explicit ComputerModel(QObject *parent = 0);
         ~ComputerModel();
 
-        QString description() const;
+        QString description() const Q_DECL_OVERRIDE;
 
         int appNameFormat() const;
         void setAppNameFormat(int format);
@@ -93,9 +95,9 @@ class ComputerModel : public ForwardingModel
         QStringList systemApplications() const;
         void setSystemApplications(const QStringList &apps);
 
-        QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+        QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
 
-        Q_INVOKABLE bool trigger(int row, const QString &actionId, const QVariant &argument);
+        Q_INVOKABLE bool trigger(int row, const QString &actionId, const QVariant &argument) Q_DECL_OVERRIDE;
 
     Q_SIGNALS:
         void appNameFormatChanged() const;
@@ -108,7 +110,7 @@ class ComputerModel : public ForwardingModel
     private:
         KConcatenateRowsProxyModel *m_concatProxy;
         RunCommandModel *m_runCommandModel;
-        FavoritesModel *m_systemAppsModel;
+        SimpleFavoritesModel *m_systemAppsModel;
         FilteredPlacesModel *m_filteredPlacesModel;
         AppEntry::NameFormat m_appNameFormat;
         QObject *m_appletInterface;
