@@ -33,6 +33,8 @@
 #include <KLocalizedString>
 #include <KStringHandler>
 #include <KMessageBox>
+#include <QNetworkDiskCache>
+#include <QStorageInfo>
 
 using namespace Attica;
 
@@ -40,7 +42,14 @@ KdePlatformDependent::KdePlatformDependent()
     : m_config(KSharedConfig::openConfig("atticarc")), m_accessManager(0), m_wallet(0)
 {
     // FIXME: Investigate how to not leak this instance witohut crashing.
-    m_accessManager = new KIO::Integration::AccessManager(0);
+    m_accessManager = new QNetworkAccessManager(0);
+
+    const QString cacheDir = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QStringLiteral("/attica");
+    QNetworkDiskCache *cache = new QNetworkDiskCache(m_accessManager);
+    QStorageInfo storageInfo(cacheDir);
+    cache->setCacheDirectory(cacheDir);
+    cache->setMaximumCacheSize(storageInfo.bytesTotal() / 1000);
+    m_accessManager->setCache(cache);
 }
 
 KdePlatformDependent::~KdePlatformDependent()
@@ -85,8 +94,7 @@ QNetworkReply* KdePlatformDependent::get(const QNetworkRequest& request)
 
 QNetworkRequest KdePlatformDependent::removeAuthFromRequest(const QNetworkRequest& request)
 {
-    QStringList noauth;
-    noauth << "no-auth-prompt" << "true";
+    const QStringList noauth = { "no-auth-prompt", "true" };
     QNetworkRequest notConstReq = const_cast<QNetworkRequest&>(request);
     notConstReq.setAttribute(QNetworkRequest::User, noauth);
     return notConstReq;
@@ -94,7 +102,7 @@ QNetworkRequest KdePlatformDependent::removeAuthFromRequest(const QNetworkReques
 
 bool KdePlatformDependent::saveCredentials(const QUrl& baseUrl, const QString& user, const QString& password)
 {
-    m_passwords[baseUrl.toString()] = QPair<QString, QString> (user, password);
+    m_passwords[baseUrl.toString()] = qMakePair(user, password);
 
     if (!m_wallet && !openWallet(true)) {
 
@@ -118,9 +126,10 @@ bool KdePlatformDependent::saveCredentials(const QUrl& baseUrl, const QString& u
         return true;
     }
 
-    QMap<QString, QString> entries;
-    entries.insert("user", user);
-    entries.insert("password", password);
+    const QMap<QString, QString> entries = {
+        { "user", user },
+        { "password", password }
+    };
     qCDebug(ATTICA_PLUGIN_LOG) << "Saved credentials in KWallet";
 
     return !m_wallet->writeMap(baseUrl.toString(), entries);
@@ -140,15 +149,10 @@ bool KdePlatformDependent::hasCredentials(const QUrl& baseUrl) const
     }
 
     KConfigGroup group(m_config, baseUrl.toString());
-    QString user;
-    user = group.readEntry("user", QString());
-    if (!user.isEmpty()) {
-        qCDebug(ATTICA_PLUGIN_LOG) << "Found credentials in KConfig";
-        return true;
-    }
 
-    qCDebug(ATTICA_PLUGIN_LOG) << "No credentials found";
-    return false;
+    const QString user = group.readEntry("user", QString());
+    qCDebug(ATTICA_PLUGIN_LOG) << "Credentials found:" << !user.isEmpty();
+    return !user.isEmpty();
 }
 
 
@@ -163,7 +167,7 @@ bool KdePlatformDependent::loadCredentials(const QUrl& baseUrl, QString& user, Q
         password = KStringHandler::obscure(group.readEntry("password", QString()));
         if (!user.isEmpty()) {
             qCDebug(ATTICA_PLUGIN_LOG) << "Successfully loaded credentials from kconfig";
-            m_passwords[baseUrl.toString()] = QPair<QString, QString> (user, password);
+            m_passwords[baseUrl.toString()] = qMakePair(user, password);
             return true;
         }
         return false;
@@ -181,7 +185,7 @@ bool KdePlatformDependent::loadCredentials(const QUrl& baseUrl, QString& user, Q
     password = entries.value("password");
     qCDebug(ATTICA_PLUGIN_LOG) << "Successfully loaded credentials.";
 
-    m_passwords[baseUrl.toString()] = QPair<QString, QString> (user, password);
+    m_passwords[baseUrl.toString()] = qMakePair(user, password);
 
     return true;
 }
