@@ -24,6 +24,7 @@
 #include "foldermodel.h"
 #include "itemviewadapter.h"
 #include "positioner.h"
+#include "screenmapper.h"
 
 #include <QApplication>
 #include <QClipboard>
@@ -39,6 +40,8 @@
 #include <QPixmap>
 #include <QQuickItem>
 #include <QQuickWindow>
+#include <QTimer>
+#include <QLoggingCategory>
 #include <qplatformdefs.h>
 
 #include <KDirWatch>
@@ -60,7 +63,6 @@
 #include <KPropertiesDialog>
 #include <KSharedConfig>
 #include <KShell>
-#include <kio_version.h>
 
 #include <KCoreDirLister>
 #include <KDirLister>
@@ -71,10 +73,16 @@
 #include <KProtocolInfo>
 #include <KRun>
 
+#include <Plasma/Applet>
+#include <Plasma/Containment>
+#include <Plasma/Corona>
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
 
+Q_LOGGING_CATEGORY(FOLDERMODEL, "plasma.containments.desktop.folder.foldermodel")
+
 DirLister::DirLister(QObject *parent) : KDirLister(parent)
 {
 }
@@ -97,11 +105,12 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
     m_dirWatch(nullptr),
     m_dragInProgress(false),
     m_urlChangedWhileDragging(false),
-    m_previewGenerator(0),
-    m_viewAdapter(0),
+    m_dropTargetPositionsCleanup(new QTimer(this)),
+    m_previewGenerator(nullptr),
+    m_viewAdapter(nullptr),
     m_actionCollection(this),
-    m_newMenu(0),
-    m_fileItemActions(0),
+    m_newMenu(nullptr),
+    m_fileItemActions(nullptr),
     m_usedByContainment(false),
     m_locked(true),
     m_sortMode(0),
@@ -110,13 +119,15 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
     m_parseDesktopFiles(false),
     m_previews(false),
     m_filterMode(NoFilter),
-    m_filterPatternMatchAll(true)
+    m_filterPatternMatchAll(true),
+    m_complete(false),
+    m_screenMapper(ScreenMapper::instance())
 {
     //needed to pass the job around with qml
     qmlRegisterType<KIO::DropJob>();
     DirLister *dirLister = new DirLister(this);
     dirLister->setDelayedMimeTypes(true);
-    dirLister->setAutoErrorHandlingEnabled(false, 0);
+    dirLister->setAutoErrorHandlingEnabled(false, nullptr);
     connect(dirLister, &DirLister::error, this, &FolderModel::dirListFailed);
     connect(dirLister, &KCoreDirLister::itemsDeleted, this, &FolderModel::evictFromIsDirCache);
 
@@ -138,9 +149,47 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
     m_dirModel->setDirLister(dirLister);
     m_dirModel->setDropsAllowed(KDirModel::DropOnDirectory | KDirModel::DropOnLocalExecutable);
 
+    /*
+     * position dropped items at the desired target position
+     * delay this via queued connection, such that the row is available and can be mapped
+     * when we emit the move request
+     */
+    connect(this, &QAbstractItemModel::rowsInserted,
+            this, [this](const QModelIndex &parent, int first, int last) {
+        for (int i = first; i <= last; ++i) {
+            const auto idx = index(i, 0, parent);
+            const auto url = itemForIndex(idx).url();
+            auto it = m_dropTargetPositions.find(url.fileName());
+            if (it != m_dropTargetPositions.end()) {
+                const auto pos = it.value();
+                m_dropTargetPositions.erase(it);
+                setSortMode(-1);
+                emit move(pos.x(), pos.y(), {url});
+            }
+        }
+    });
+    /*
+     * Dropped files may not actually show up as new files, e.g. when we overwrite
+     * an existing file. Or files that fail to be listed by the dirLister, or...
+     * To ensure we don't grow the map indefinitely, clean it up periodically.
+     * The cleanup timer is (re)started whenever we modify the map. We use a quite
+     * high interval of 10s. This should ensure, that we don't accidentally wipe
+     * the mapping when we actually still want to use it. Since the time between
+     * adding an entry in the map and it showing up in the model should be
+     * small, this should rarely, if ever happen.
+     */
+    m_dropTargetPositionsCleanup->setInterval(10000);
+    m_dropTargetPositionsCleanup->setSingleShot(true);
+    connect(m_dropTargetPositionsCleanup, &QTimer::timeout, this, [this]() {
+        if (!m_dropTargetPositions.isEmpty()) {
+            qCDebug(FOLDERMODEL) << "clearing drop target positions after timeout:" << m_dropTargetPositions;
+            m_dropTargetPositions.clear();
+        }
+    });
+
     m_selectionModel = new QItemSelectionModel(this, this);
-    connect(m_selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(selectionChanged(QItemSelection,QItemSelection)));
+    connect(m_selectionModel, &QItemSelectionModel::selectionChanged,
+            this, &FolderModel::selectionChanged);
 
     setSourceModel(m_dirModel);
 
@@ -155,6 +204,12 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
 
 FolderModel::~FolderModel()
 {
+    if (m_usedByContainment) {
+        // disconnect so we don't handle signals from the screen mapper when
+        // removeScreen is called
+        m_screenMapper->disconnect(this);
+        m_screenMapper->removeScreen(m_screen, url());
+    }
 }
 
 QHash< int, QByteArray > FolderModel::roleNames() const
@@ -181,6 +236,44 @@ QHash< int, QByteArray > FolderModel::staticRoleNames()
     return roleNames;
 }
 
+void FolderModel::classBegin()
+{
+}
+
+void FolderModel::componentComplete()
+{
+    m_complete = true;
+    invalidate();
+}
+
+void FolderModel::invalidateIfComplete()
+{
+    if (!m_complete) {
+        return;
+    }
+
+    invalidate();
+}
+
+void FolderModel::invalidateFilterIfComplete()
+{
+    if (!m_complete) {
+        return;
+    }
+
+    invalidateFilter();
+}
+
+void FolderModel::newFileMenuItemCreated(const QUrl &url)
+{
+    if (m_usedByContainment) {
+        m_screenMapper->addMapping(url.toString(), m_screen, ScreenMapper::DelayedSignal);
+        m_dropTargetPositions.insert(url.fileName(), m_menuPosition);
+        m_menuPosition = {};
+        m_dropTargetPositionsCleanup->start();
+    }
+}
+
 QString FolderModel::url() const
 {
     return m_url;
@@ -195,6 +288,8 @@ void FolderModel::setUrl(const QString& url)
         return;
     }
 
+    const auto oldUrl = m_url;
+
     beginResetModel();
     m_url = url;
     m_isDirCache.clear();
@@ -211,6 +306,7 @@ void FolderModel::setUrl(const QString& url)
 
     if (m_dirWatch) {
         delete m_dirWatch;
+        m_dirWatch = nullptr;
     }
 
     if (resolvedUrl.isValid()) {
@@ -225,6 +321,11 @@ void FolderModel::setUrl(const QString& url)
     }
 
     emit iconNameChanged();
+
+    if (m_usedByContainment) {
+        m_screenMapper->removeScreen(m_screen, oldUrl);
+        m_screenMapper->addScreen(m_screen, url);
+    }
 }
 
 QUrl FolderModel::resolvedUrl() const
@@ -236,7 +337,7 @@ QUrl FolderModel::resolve(const QString& url)
 {
     QUrl resolvedUrl;
 
-    if (url.startsWith('~')) {
+    if (url.startsWith(QLatin1Char('~'))) {
         resolvedUrl = QUrl::fromLocalFile(KShell::tildeExpand(url));
     } else {
         resolvedUrl = QUrl::fromUserInput(url);
@@ -296,6 +397,10 @@ void FolderModel::setUsedByContainment(bool used)
             action->setIcon(m_usedByContainment ? QIcon::fromTheme(QStringLiteral("user-desktop")) : QIcon::fromTheme(QStringLiteral("view-refresh")));
         }
 
+        m_screenMapper->disconnect(this);
+        connect(m_screenMapper, &ScreenMapper::screensChanged, this, &FolderModel::invalidateFilterIfComplete);
+        connect(m_screenMapper, &ScreenMapper::screenMappingChanged, this, &FolderModel::invalidateFilterIfComplete);
+
         emit usedByContainmentChanged();
     }
 }
@@ -333,7 +438,7 @@ void FolderModel::setSortMode(int mode)
         if (mode == -1 /* Unsorted */) {
             setDynamicSortFilter(false);
         } else {
-            invalidate();
+            invalidateIfComplete();
             sort(m_sortMode, m_sortDesc ? Qt::DescendingOrder : Qt::AscendingOrder);
             setDynamicSortFilter(true);
         }
@@ -353,7 +458,7 @@ void FolderModel::setSortDesc(bool desc)
         m_sortDesc = desc;
 
         if (m_sortMode != -1 /* Unsorted */) {
-            invalidate();
+            invalidateIfComplete();
             sort(m_sortMode, m_sortDesc ? Qt::DescendingOrder : Qt::AscendingOrder);
         }
 
@@ -372,7 +477,7 @@ void FolderModel::setSortDirsFirst(bool enable)
         m_sortDirsFirst = enable;
 
         if (m_sortMode != -1 /* Unsorted */) {
-            invalidate();
+            invalidateIfComplete();
             sort(m_sortMode, m_sortDesc ? Qt::DescendingOrder : Qt::AscendingOrder);
         }
 
@@ -463,7 +568,7 @@ void FolderModel::setFilterMode(int filterMode)
     if (m_filterMode != (FilterMode)filterMode) {
         m_filterMode = (FilterMode)filterMode;
 
-        invalidateFilter();
+        invalidateFilterIfComplete();
 
         emit filterModeChanged();
     }
@@ -483,8 +588,9 @@ void FolderModel::setFilterPattern(const QString &pattern)
     m_filterPattern = pattern;
     m_filterPatternMatchAll = (pattern == QLatin1String("*"));
 
-    const QStringList patterns = pattern.split(' ');
+    const QStringList patterns = pattern.split(QLatin1Char(' '));
     m_regExps.clear();
+    m_regExps.reserve(patterns.count());
 
     foreach (const QString &pattern, patterns) {
         QRegExp rx(pattern);
@@ -493,7 +599,7 @@ void FolderModel::setFilterPattern(const QString &pattern)
         m_regExps.append(rx);
     }
 
-    invalidateFilter();
+    invalidateFilterIfComplete();
 
     emit filterPatternChanged();
 }
@@ -511,12 +617,24 @@ void FolderModel::setFilterMimeTypes(const QStringList &mimeList)
 
         m_mimeSet = set;
 
-        invalidateFilter();
+        invalidateFilterIfComplete();
 
         emit filterMimeTypesChanged();
     }
 }
 
+void FolderModel::setScreen(int screen)
+{
+    if (m_screen == screen)
+        return;
+
+    m_screen = screen;
+    if (m_usedByContainment) {
+        m_screenMapper->addScreen(screen, url());
+    }
+    emit screenChanged();
+}
+
 KFileItem FolderModel::rootItem() const
 {
     return m_dirModel->dirLister()->rootItem();
@@ -544,7 +662,7 @@ void FolderModel::cd(int row)
         const KFileItem  item = itemForIndex(idx);
         if (m_parseDesktopFiles && item.isDesktopFile()) {
             const KDesktopFile file(item.targetUrl().path());
-            if (file.readType() == QLatin1String("Link")) {
+            if (file.hasLinkType()) {
                 setUrl(file.readUrl());
             }
         }
@@ -569,7 +687,7 @@ void FolderModel::run(int row)
         url.setScheme(QStringLiteral("file"));
     }
 
-    KRun *run = new KRun(url, 0);
+    KRun *run = new KRun(url, nullptr);
     // On desktop:/ we want to be able to run .desktop files right away,
     // otherwise ask for security reasons. We also don't use the targetUrl()
     // from above since we don't want the resolved /home/foo/Desktop URL.
@@ -638,7 +756,7 @@ int FolderModel::fileExtensionBoundary(int row)
     return boundary;
 }
 
-bool FolderModel::hasSelection()
+bool FolderModel::hasSelection() const
 {
     return m_selectionModel->hasSelection();
 }
@@ -759,11 +877,12 @@ void FolderModel::setDragHotSpotScrollOffset(int x, int y)
 
 QPoint FolderModel::dragCursorOffset(int row)
 {
-    if (!m_dragImages.contains(row)) {
-        return QPoint(-1, -1);
+    DragImage *image = m_dragImages.value(row);
+    if (!image) {
+        return QPoint(0, 0);
     }
 
-    return m_dragImages.value(row)->cursorOffset;
+    return image->cursorOffset;
 }
 
 void FolderModel::addDragImage(QDrag *drag, int x, int y)
@@ -851,7 +970,7 @@ void FolderModel::dragSelectedInternal(int x, int y)
     emit dataChanged(m_dragIndexes.first(), m_dragIndexes.last(), QVector<int>() << BlankRole);
 
     QModelIndexList sourceDragIndexes;
-
+    sourceDragIndexes.reserve(m_dragIndexes.count());
     foreach (const QModelIndex &index, m_dragIndexes) {
         sourceDragIndexes.append(mapToSource(index));
     }
@@ -882,6 +1001,16 @@ void FolderModel::dragSelectedInternal(int x, int y)
     }
 }
 
+static bool isDropBetweenSharedViews(const QList<QUrl> &urls, const QUrl &folderUrl)
+{
+    for (const auto &url : urls) {
+        if (folderUrl != url.adjusted(QUrl::RemoveFilename)) {
+            return false;
+        }
+    }
+    return true;
+}
+
 void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
 {
     QMimeData *mimeData = qobject_cast<QMimeData *>(dropEvent->property("mimeData").value<QObject *>());
@@ -890,19 +1019,6 @@ void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
         return;
     }
 
-    if (m_dragInProgress && row == -1 && !m_urlChangedWhileDragging) {
-        if (m_locked || mimeData->urls().isEmpty()) {
-            return;
-        }
-
-        setSortMode(-1);
-
-        emit move(dropEvent->property("x").toInt(), dropEvent->property("y").toInt(),
-            mimeData->urls());
-
-        return;
-    }
-
     QModelIndex idx;
     KFileItem item;
 
@@ -923,7 +1039,7 @@ void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
     } else if (m_parseDesktopFiles && item.isDesktopFile()) {
         const KDesktopFile file(item.targetUrl().path());
 
-        if (file.readType() == QLatin1String("Link")) {
+        if (file.hasLinkType()) {
             dropTargetUrl = QUrl(file.readUrl());
         } else {
             dropTargetUrl = item.mostLocalUrl();
@@ -932,6 +1048,50 @@ void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
         dropTargetUrl = item.mostLocalUrl();
     }
 
+    auto dropTargetFolderUrl = dropTargetUrl;
+    if (dropTargetFolderUrl.fileName() == QLatin1String(".")) {
+        // the target URL for desktop:/ is e.g. 'file://home/user/Desktop/.'
+        dropTargetFolderUrl = dropTargetFolderUrl.adjusted(QUrl::RemoveFilename);
+    }
+
+    // use dropTargetUrl to resolve desktop:/ to the actual file location which is also used by the mime data
+    /* QMimeData operates on local URLs, but the dir lister and thus screen mapper and positioner may
+     * use a fancy scheme like desktop:/ instead. Ensure we always use the latter to properly map URLs,
+     * i.e. go from file:///home/user/Desktop/file to desktop:/file
+     */
+    auto mappableUrl = [this, dropTargetFolderUrl](const QUrl &url) -> QString {
+        QString mappedUrl = url.toString();
+        if (dropTargetFolderUrl != m_dirModel->dirLister()->url()) {
+            const auto local = dropTargetFolderUrl.toString();
+            const auto internal = m_dirModel->dirLister()->url().toString();
+            if (mappedUrl.startsWith(local)) {
+                mappedUrl.replace(0, local.size(), internal);
+            }
+        }
+        return mappedUrl;
+    };
+
+    const int x = dropEvent->property("x").toInt();
+    const int y = dropEvent->property("y").toInt();
+    const QPoint dropPos = {x, y};
+
+    if (m_dragInProgress && row == -1 && !m_urlChangedWhileDragging) {
+        if (m_locked || mimeData->urls().isEmpty()) {
+            return;
+        }
+
+        setSortMode(-1);
+
+        for (const auto &url : mimeData->urls()) {
+            m_dropTargetPositions.insert(url.fileName(), dropPos);
+            m_screenMapper->addMapping(mappableUrl(url), m_screen, ScreenMapper::DelayedSignal);
+            m_screenMapper->removeItemFromDisabledScreen(mappableUrl(url));
+        }
+        emit move(x, y, mimeData->urls());
+
+        return;
+    }
+
     if (mimeData->hasFormat(QStringLiteral("application/x-kde-ark-dndextract-service")) &&
         mimeData->hasFormat(QStringLiteral("application/x-kde-ark-dndextract-path"))) {
         const QString remoteDBusClient = mimeData->data(QStringLiteral("application/x-kde-ark-dndextract-service"));
@@ -943,7 +1103,7 @@ void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
                                             QStringLiteral("extractSelectedFilesTo"));
         message.setArguments({dropTargetUrl.toDisplayString(QUrl::PreferLocalFile)});
 
-        QDBusConnection::sessionBus().call(message);
+        QDBusConnection::sessionBus().call(message, QDBus::NoBlock);
 
         return;
     }
@@ -952,25 +1112,32 @@ void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
         return;
     }
 
-    QPoint pos;
-    pos.setX(dropEvent->property("x").toInt());
-    pos.setY(dropEvent->property("y").toInt());
 
-    pos = target->mapToScene(pos).toPoint();
-    pos = target->window()->mapToGlobal(pos);
+    if (m_usedByContainment) {
+        if (isDropBetweenSharedViews(mimeData->urls(), dropTargetFolderUrl)) {
+            setSortMode(-1);
+            for (const auto &url : mimeData->urls()) {
+                m_dropTargetPositions.insert(url.fileName(), dropPos);
+                m_screenMapper->addMapping(mappableUrl(url), m_screen, ScreenMapper::DelayedSignal);
+                m_screenMapper->removeItemFromDisabledScreen(mappableUrl(url));
+            }
+            m_dropTargetPositionsCleanup->start();
+            return;
+        }
+    }
 
     Qt::DropAction proposedAction((Qt::DropAction)dropEvent->property("proposedAction").toInt());
     Qt::DropActions possibleActions(dropEvent->property("possibleActions").toInt());
     Qt::MouseButtons buttons(dropEvent->property("buttons").toInt());
     Qt::KeyboardModifiers modifiers(dropEvent->property("modifiers").toInt());
 
+    auto pos = target->mapToScene(dropPos).toPoint();
+    pos = target->window()->mapToGlobal(pos);
     QDropEvent ev(pos, possibleActions, mimeData, buttons, modifiers);
     ev.setDropAction(proposedAction);
 
     KIO::DropJob *dropJob = KIO::drop(&ev, dropTargetUrl);
     dropJob->uiDelegate()->setAutoErrorHandlingEnabled(true);
-    const int x = dropEvent->property("x").toInt();
-    const int y = dropEvent->property("y").toInt();
 
     // The QMimeData we extract from the DropArea's drop event is deleted as soon as this method
     // ends but we need to keep a copy for when popupMenuAboutToShow fires.
@@ -979,10 +1146,52 @@ void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
         mimeCopy->setData(format, mimeData->data(format));
     }
 
-    connect(dropJob, static_cast<void(KIO::DropJob::*)(const KFileItemListProperties &)>(&KIO::DropJob::popupMenuAboutToShow), this, [this, mimeCopy, x, y, dropJob](const KFileItemListProperties &) {
+    connect(dropJob, &KIO::DropJob::popupMenuAboutToShow, this, [this, mimeCopy, x, y, dropJob](const KFileItemListProperties &) {
         emit popupMenuAboutToShow(dropJob, mimeCopy, x, y);
         mimeCopy->deleteLater();
     });
+
+    /*
+     * Position files that come from a drag'n'drop event at the drop event
+     * target position. To do so, we first listen to copy job to figure out
+     * the target URL. Then we store the position of this drop event in the
+     * hash and eventually trigger a move request when we get notified about
+     * the new file event from the source model.
+     */
+    connect(dropJob, &KIO::DropJob::copyJobStarted, this, [this, dropPos, dropTargetUrl](KIO::CopyJob* copyJob) {
+        auto map = [this, dropPos, dropTargetUrl](const QUrl &targetUrl) {
+            m_dropTargetPositions.insert(targetUrl.fileName(), dropPos);
+            m_dropTargetPositionsCleanup->start();
+
+            if (m_usedByContainment) {
+                // assign a screen for the item before the copy is actually done, so
+                // filterAcceptsRow doesn't assign the default screen to it
+                QUrl url = QUrl::fromUserInput(m_url, {}, QUrl::AssumeLocalFile);
+                // if the folderview's folder is a standard path, just use the targetUrl for mapping
+                if (targetUrl.toString().startsWith(url.toString())) {
+                    m_screenMapper->addMapping(targetUrl.toString(), m_screen, ScreenMapper::DelayedSignal);
+                } else if (targetUrl.toString().startsWith(dropTargetUrl.toString())) {
+                    // if the folderview's folder is a special path, like desktop:// , we need to convert
+                    // the targetUrl file:// path to a desktop:/ path for mapping
+                    auto destPath = dropTargetUrl.path();
+                    auto filePath = targetUrl.path();
+                    if (filePath.startsWith(destPath)) {
+                        url.setPath(filePath.remove(0, destPath.length()));
+                        m_screenMapper->addMapping(url.toString(), m_screen, ScreenMapper::DelayedSignal);
+                    }
+                }
+            }
+        };
+        // remember drop target position for target URL and forget about the source URL
+        connect(copyJob, &KIO::CopyJob::copyingDone,
+                this, [this, map](KIO::Job *, const QUrl &, const QUrl &targetUrl, const QDateTime &, bool, bool) {
+            map(targetUrl);
+        });
+        connect(copyJob, &KIO::CopyJob::copyingLinkDone,
+                this, [this, map](KIO::Job *, const QUrl &, const QString &, const QUrl &targetUrl) {
+            map(targetUrl);
+        });
+    });
 }
 
 void FolderModel::dropCwd(QObject* dropEvent)
@@ -1004,7 +1213,7 @@ void FolderModel::dropCwd(QObject* dropEvent)
                                             QStringLiteral("extractSelectedFilesTo"));
         message.setArguments(QVariantList() << m_dirModel->dirLister()->url().adjusted(QUrl::PreferLocalFile).toString());
 
-        QDBusConnection::sessionBus().call(message);
+        QDBusConnection::sessionBus().call(message, QDBus::NoBlock);
     } else {
         Qt::DropAction proposedAction((Qt::DropAction)dropEvent->property("proposedAction").toInt());
         Qt::DropActions possibleActions(dropEvent->property("possibleActions").toInt());
@@ -1019,7 +1228,7 @@ void FolderModel::dropCwd(QObject* dropEvent)
     }
 }
 
-void FolderModel::selectionChanged(QItemSelection selected, QItemSelection deselected)
+void FolderModel::selectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
 {
     QModelIndexList indices = selected.indexes();
     indices.append(deselected.indexes());
@@ -1027,7 +1236,7 @@ void FolderModel::selectionChanged(QItemSelection selected, QItemSelection desel
     QVector<int> roles;
     roles.append(SelectedRole);
 
-    foreach(const QModelIndex index, indices) {
+    foreach(const QModelIndex &index, indices) {
         emit dataChanged(index, index, roles);
     }
 
@@ -1088,7 +1297,7 @@ QVariant FolderModel::data(const QModelIndex& index, int role) const
         if (m_parseDesktopFiles && item.isDesktopFile()) {
             const KDesktopFile file(item.targetUrl().path());
 
-            if (file.readType() == QLatin1String("Link")) {
+            if (file.hasLinkType()) {
                 return file.readUrl();
             }
         }
@@ -1130,7 +1339,7 @@ bool FolderModel::isDir(const QModelIndex &index, const KDirModel *dirModel) con
         // Check if the desktop file is a link to a directory
         KDesktopFile file(item.targetUrl().path());
 
-        if (file.readType() == QLatin1String("Link")) {
+        if (file.hasLinkType()) {
             const QUrl url(file.readUrl());
 
             if (!m_isDirCache.contains(item.url()) && KProtocolInfo::protocolClass(url.scheme()) == QStringLiteral(":local")) {
@@ -1163,6 +1372,7 @@ void FolderModel::statResult(KJob *job)
 void FolderModel::evictFromIsDirCache(const KFileItemList& items)
 {
     foreach (const KFileItem &item, items) {
+        m_screenMapper->removeFromMap(item.url().toString());
         m_isDirCache.remove(item.url());
     }
 }
@@ -1284,13 +1494,34 @@ inline bool FolderModel::matchPattern(const KFileItem &item) const
 
 bool FolderModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
 {
+    const KDirModel *dirModel = static_cast<KDirModel*>(sourceModel());
+    const KFileItem item = dirModel->itemForIndex(dirModel->index(sourceRow, KDirModel::Name, sourceParent));
+
+    if (m_usedByContainment) {
+        const QString name = item.url().toString();
+        const int screen = m_screenMapper->screenForItem(name);
+        // don't do anything if the folderview is not associated with a screen
+        if (m_screen != -1) {
+            if (screen == -1) {
+                // The item is not associated with a screen, probably because this is the first
+                // time we see it or the folderview was previously used as a regular applet.
+                // Associated with this folderview if the view is on the first available screen
+                if (m_screen == m_screenMapper->firstAvailableScreen(url())) {
+                    m_screenMapper->addMapping(name, m_screen, ScreenMapper::DelayedSignal);
+                } else {
+                    return false;
+                }
+            } else if (m_screen != screen) {
+                // the item belongs to a different screen, filter it out
+                return false;
+            }
+        }
+    }
+
     if (m_filterMode == NoFilter) {
         return true;
     }
 
-    const KDirModel *dirModel = static_cast<KDirModel*>(sourceModel());
-    const KFileItem item = dirModel->itemForIndex(dirModel->index(sourceRow, KDirModel::Name, sourceParent));
-
     if (m_filterMode == FilterShowMatches) {
         return (matchPattern(item) && matchMimeType(item));
     } else {
@@ -1302,17 +1533,17 @@ void FolderModel::createActions()
 {
     KIO::FileUndoManager *manager = KIO::FileUndoManager::self();
 
-    QAction *cut = KStandardAction::cut(this, SLOT(cut()), this);
-    QAction *copy = KStandardAction::copy(this, SLOT(copy()), this);
+    QAction *cut = KStandardAction::cut(this, &FolderModel::cut, this);
+    QAction *copy = KStandardAction::copy(this, &FolderModel::copy, this);
 
-    QAction *undo = KStandardAction::undo(manager, SLOT(undo()), this);
+    QAction *undo = KStandardAction::undo(manager, &KIO::FileUndoManager::undo, this);
     undo->setEnabled(manager->undoAvailable());
     undo->setShortcutContext(Qt::WidgetShortcut);
     connect(manager, SIGNAL(undoAvailable(bool)), undo, SLOT(setEnabled(bool)));
     connect(manager, &KIO::FileUndoManager::undoTextChanged, this, &FolderModel::undoTextChanged);
 
-    QAction *paste = KStandardAction::paste(this, SLOT(paste()), this);
-    QAction *pasteTo = KStandardAction::paste(this, SLOT(pasteTo()), this);
+    QAction *paste = KStandardAction::paste(this, &FolderModel::paste, this);
+    QAction *pasteTo = KStandardAction::paste(this, &FolderModel::pasteTo, this);
 
     QAction *reload = new QAction(i18n("&Reload"), this);
     connect(reload, &QAction::triggered, this, &FolderModel::refresh);
@@ -1354,8 +1585,10 @@ void FolderModel::createActions()
 
     m_newMenu = new KNewFileMenu(&m_actionCollection, QStringLiteral("newMenu"), QApplication::desktop());
     m_newMenu->setModal(false);
+    connect(m_newMenu, &KNewFileMenu::directoryCreated, this, &FolderModel::newFileMenuItemCreated);
+    connect(m_newMenu, &KNewFileMenu::fileCreated, this, &FolderModel::newFileMenuItemCreated);
 
-    m_copyToMenu = new KFileCopyToMenu(Q_NULLPTR);
+    m_copyToMenu = new KFileCopyToMenu(nullptr);
 }
 
 QAction* FolderModel::action(const QString &name) const
@@ -1373,6 +1606,8 @@ void FolderModel::updateActions()
     if (m_newMenu) {
         m_newMenu->checkUpToDate();
         m_newMenu->setPopupFiles(m_dirModel->dirLister()->url());
+        // we need to set here as well, when the menu is shown via AppletInterface::eventFilter
+        m_menuPosition = QCursor::pos();
     }
 
     const bool isTrash = (resolvedUrl().scheme() == QLatin1String("trash"));
@@ -1468,7 +1703,7 @@ void FolderModel::openContextMenu(QQuickItem *visualParent)
         // Check if we're showing the menu for the trash link
         if (items.count() == 1 && items.at(0).isDesktopFile()) {
             KDesktopFile file(items.at(0).localPath());
-            if (file.readType() == QLatin1String("Link") && file.readUrl() == QLatin1String("trash:/")) {
+            if (file.hasLinkType() && file.readUrl() == QLatin1String("trash:/")) {
                 isTrashLink = true;
             }
         }
@@ -1522,9 +1757,7 @@ void FolderModel::openContextMenu(QQuickItem *visualParent)
         m_fileItemActions->addServiceActionsTo(menu);
         menu->addSeparator();
         // Plugin actions
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 27, 0)
         m_fileItemActions->addPluginActionsTo(menu);
-#endif
 
         // Copy To, Move To
         KSharedConfig::Ptr dolphin = KSharedConfig::openConfig(QStringLiteral("dolphinrc"));
@@ -1540,7 +1773,7 @@ void FolderModel::openContextMenu(QQuickItem *visualParent)
             QAction *act = new QAction(menu);
             act->setText(i18n("&Properties"));
             QObject::connect(act, &QAction::triggered, [this, items]() {
-                    KPropertiesDialog::showDialog(items, Q_NULLPTR, false /*non modal*/);
+                    KPropertiesDialog::showDialog(items, nullptr, false /*non modal*/);
             });
             menu->addAction(act);
         }
@@ -1548,10 +1781,11 @@ void FolderModel::openContextMenu(QQuickItem *visualParent)
     }
 
     if (visualParent) {
-        menu->popup(visualParent->mapToGlobal(QPointF(0, visualParent->height())).toPoint());
+        m_menuPosition = visualParent->mapToGlobal(QPointF(0, visualParent->height())).toPoint();
     } else {
-        menu->popup(QCursor::pos());
+        m_menuPosition = QCursor::pos();
     }
+    menu->popup(m_menuPosition);
     connect(menu, &QMenu::aboutToHide, [menu]() { menu->deleteLater(); });
 }
 
@@ -1620,6 +1854,40 @@ void FolderModel::refresh()
     m_dirModel->dirLister()->updateDirectory(m_dirModel->dirLister()->url());
 }
 
+QObject *FolderModel::appletInterface() const
+{
+    return m_appletInterface;
+}
+
+void FolderModel::setAppletInterface(QObject *appletInterface)
+{
+    if (m_appletInterface != appletInterface) {
+        Q_ASSERT(!m_appletInterface);
+
+        m_appletInterface = appletInterface;
+
+        if (appletInterface) {
+            Plasma::Applet *applet = appletInterface->property("_plasma_applet").value<Plasma::Applet *>();
+
+            if (applet) {
+                Plasma::Containment *containment = applet->containment();
+
+                if (containment) {
+                    Plasma::Corona *corona = containment->corona();
+
+                    if (corona) {
+                        m_screenMapper->setCorona(corona);
+                    }
+                    setScreen(containment->screen());
+                    connect(containment, &Plasma::Containment::screenChanged, this, &FolderModel::setScreen);
+                }
+            }
+        }
+
+        emit appletInterfaceChanged();
+    }
+}
+
 void FolderModel::moveSelectedToTrash()
 {
     if (!m_selectionModel->hasSelection()) {
@@ -1657,7 +1925,7 @@ void FolderModel::openSelected()
 
     const QList<QUrl> urls = selectedUrls(false);
     for (const QUrl &url : urls) {
-        (void) new KRun(url, Q_NULLPTR);
+        (void) new KRun(url, nullptr);
     }
 }
 
