@@ -24,6 +24,7 @@
 
 #include <QImage>
 #include <QItemSelection>
+#include <QQmlParserStatus>
 #include <QPointer>
 #include <QSortFilterProxyModel>
 #include <QStringList>
@@ -37,6 +38,8 @@
 
 #include <KNewFileMenu>
 
+#include "folderplugin_private_export.h"
+
 class QDrag;
 class QItemSelectionModel;
 class QQuickItem;
@@ -54,24 +57,27 @@ namespace KIO {
     class DropJob;
 }
 
+class ScreenMapper;
+
 class DirLister : public KDirLister
 {
     Q_OBJECT
 
     public:
-        DirLister(QObject *parent = 0);
+        explicit DirLister(QObject *parent = nullptr);
         ~DirLister();
 
     Q_SIGNALS:
         void error(const QString &string);
 
     protected:
-        void handleError(KIO::Job *job) Q_DECL_OVERRIDE;
+        void handleError(KIO::Job *job) override;
 };
 
-class FolderModel : public QSortFilterProxyModel
+class FOLDERPLUGIN_TESTS_EXPORT FolderModel : public QSortFilterProxyModel, public QQmlParserStatus
 {
     Q_OBJECT
+    Q_INTERFACES(QQmlParserStatus)
 
     Q_PROPERTY(QString url READ url WRITE setUrl NOTIFY urlChanged)
     Q_PROPERTY(QString iconName READ iconName NOTIFY iconNameChanged)
@@ -92,6 +98,7 @@ class FolderModel : public QSortFilterProxyModel
     Q_PROPERTY(QString filterPattern READ filterPattern WRITE setFilterPattern NOTIFY filterPatternChanged)
     Q_PROPERTY(QStringList filterMimeTypes READ filterMimeTypes WRITE setFilterMimeTypes NOTIFY filterMimeTypesChanged)
     Q_PROPERTY(QObject* newMenu READ newMenu CONSTANT)
+    Q_PROPERTY(QObject* appletInterface READ appletInterface WRITE setAppletInterface NOTIFY appletInterfaceChanged);
 
     public:
         enum DataRole {
@@ -122,12 +129,15 @@ class FolderModel : public QSortFilterProxyModel
         };
         Q_ENUM(Status)
 
-        FolderModel(QObject *parent = 0);
+        explicit FolderModel(QObject *parent = nullptr);
         ~FolderModel();
 
-        QHash<int, QByteArray> roleNames() const Q_DECL_OVERRIDE;
+        QHash<int, QByteArray> roleNames() const override;
         static QHash<int, QByteArray> staticRoleNames();
 
+        void classBegin() override;
+        void componentComplete() override;
+
         QString url() const;
         void setUrl(const QString &url);
 
@@ -178,6 +188,9 @@ class FolderModel : public QSortFilterProxyModel
         QStringList filterMimeTypes() const;
         void setFilterMimeTypes(const QStringList &mimeList);
 
+        QObject *appletInterface() const;
+        void setAppletInterface(QObject *appletInterface);
+
         KFileItem rootItem() const;
 
         Q_INVOKABLE void up();
@@ -189,7 +202,7 @@ class FolderModel : public QSortFilterProxyModel
         Q_INVOKABLE void rename(int row, const QString &name);
         Q_INVOKABLE int fileExtensionBoundary(int row);
 
-        Q_INVOKABLE bool hasSelection();
+        Q_INVOKABLE bool hasSelection() const;
         Q_INVOKABLE bool isSelected(int row);
         Q_INVOKABLE void setSelected(int row);
         Q_INVOKABLE void toggleSelected(int row);
@@ -216,11 +229,11 @@ class FolderModel : public QSortFilterProxyModel
 
         Q_INVOKABLE void linkHere(const QUrl &sourceUrl);
 
-        QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+        QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
         int indexForUrl(const QUrl &url) const;
         KFileItem itemForIndex(const QModelIndex &index) const;
         bool isDir(const QModelIndex &index, const KDirModel *dirModel) const;
-        bool lessThan(const QModelIndex &left, const QModelIndex &right) const Q_DECL_OVERRIDE;
+        bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
         Qt::DropActions supportedDragActions() const override;
 
         Q_INVOKABLE void paste();
@@ -231,6 +244,8 @@ class FolderModel : public QSortFilterProxyModel
         Q_INVOKABLE void undo();
         Q_INVOKABLE void refresh();
 
+        void setScreen(int screen);
+
     Q_SIGNALS:
         void urlChanged() const;
         void listingCompleted() const;
@@ -252,12 +267,14 @@ class FolderModel : public QSortFilterProxyModel
         void filterModeChanged() const;
         void filterPatternChanged() const;
         void filterMimeTypesChanged() const;
+        void screenChanged() const;
+        void appletInterfaceChanged() const;
         void requestRename() const;
         void move(int x, int y, QList<QUrl> urls);
         void popupMenuAboutToShow(KIO::DropJob *dropJob, QMimeData *mimeData, int x, int y);
 
     protected:
-        bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const Q_DECL_OVERRIDE;
+        bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
         bool matchMimeType(const KFileItem &item) const;
         bool matchPattern(const KFileItem &item) const;
 
@@ -266,12 +283,15 @@ class FolderModel : public QSortFilterProxyModel
         void dirListFailed(const QString &error);
         void statResult(KJob *job);
         void evictFromIsDirCache(const KFileItemList &items);
-        void selectionChanged(QItemSelection selected, QItemSelection deselected);
+        void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
         void pasteTo();
         void moveSelectedToTrash();
         void emptyTrashBin();
         void restoreSelectedFromTrash();
         void undoTextChanged(const QString &text);
+        void invalidateIfComplete();
+        void invalidateFilterIfComplete();
+        void newFileMenuItemCreated(const QUrl &url);
 
     private:
         struct DragImage {
@@ -298,6 +318,10 @@ class FolderModel : public QSortFilterProxyModel
         QPoint m_dragHotSpotScrollOffset;
         bool m_dragInProgress;
         bool m_urlChangedWhileDragging;
+        // target filename to target position of a drop event, note that this deliberately
+        // is not using the URL to easily support desktop:/ URL schemes
+        QHash<QString, QPoint> m_dropTargetPositions;
+        QTimer *m_dropTargetPositionsCleanup;
         QPointer<KFilePreviewGenerator> m_previewGenerator;
         QPointer<KAbstractViewAdapter> m_viewAdapter;
         KActionCollection m_actionCollection;
@@ -319,6 +343,11 @@ class FolderModel : public QSortFilterProxyModel
         bool m_filterPatternMatchAll;
         QSet<QString> m_mimeSet;
         QList<QRegExp> m_regExps;
+        int m_screen = -1;
+        ScreenMapper *m_screenMapper = nullptr;
+        QObject *m_appletInterface = nullptr;
+        bool m_complete;
+        QPoint m_menuPosition;
 };
 
 #endif
