@@ -30,7 +30,7 @@
 class XInputEventNotifier;
 class LayoutTrayIcon;
 class KeyboardConfig;
-class Rules;
+struct Rules;
 
 class Q_DECL_EXPORT KeyboardDaemon : public KDEDModule
 {
