@@ -157,7 +157,7 @@ public:
 		switchingPolicy(switchingPolicy_) {}
 
     bool startElement(const QString &/*namespaceURI*/, const QString &/*localName*/,
-                      const QString &qName, const QXmlAttributes &attributes) {
+                      const QString &qName, const QXmlAttributes &attributes) Q_DECL_OVERRIDE {
 
     	if( qName == ROOT_NODE ) {
     		if( attributes.value(VERSION_ATTRIBUTE) != VERSION )
