@@ -541,6 +541,9 @@ void runRdb( uint flags )
     //user has set to use when under wayland - as X apps will be scaled by the compositor
     if (KWindowSystem::isPlatformWayland()) {
         dpi = cfgfonts.readEntry( "forceFontDPIWayland", 0);
+        if (dpi == 0) { //with wayland we want xwayland to run at 96 dpi (unless set otherwise) as we have wayland scaling on top
+            dpi = 96;
+        }
     } else {
         dpi = cfgfonts.readEntry( "forceFontDPI", 0);
     }
