@@ -116,7 +116,7 @@ public:
         }
     }
 
-    int type() const { return 1001; }
+    int type() const Q_DECL_OVERRIDE { return 1001; }
     Category category() const { return m_cat; }
     CaptureCategory captureCategory() const { return m_capcat; }
     ObjectDescriptionType odtype() const { return m_odtype; }
@@ -877,7 +877,7 @@ void DevicePreference::on_testPlaybackButton_toggled(bool down)
             createPath(m_media, m_audioOutput);
             static QUrl testUrl = QUrl::fromLocalFile(QStandardPaths::locate(
                                                           QStandardPaths::GenericDataLocation,
-                                                          QStringLiteral("sounds/KDE-Sys-Log-In.ogg")));
+                                                          QStringLiteral("sounds/Oxygen-Sys-Log-In.ogg")));
             m_media->setCurrentSource(testUrl);
             connect(m_media, &MediaObject::finished, testPlaybackButton, &QToolButton::toggle);
 
